pub struct RealtimeClient { /* private fields */ }Implementations
Sourceimpl RealtimeClient
impl RealtimeClient
pub fn new(config: RealtimeClientConfig) -> Self
Sourcepub async fn connect(&mut self) -> Result<Receiver<Event>, AuraxisError>
pub async fn connect(&mut self) -> Result<Receiver<Event>, AuraxisError>
Send a message to the websocket connection.
This function will be spawned as a task and will run concurrently to the rest of the application. It will continually check for messages on the receiver end of the channel. When a message is received, it will be sent to the websocket connection. If sending the message fails, the error is logged and the connection is closed.
Arguments
websocket- The websocket connection to send messages to.receiver- The channel receiving messages to send.
Errors
This function will return an error if the websocket connection cannot be created.
pub fn subscribe(&mut self, subscription: SubscriptionSettings)
pub fn clear_subscribe(&mut self, subscription: SubscriptionSettings)
pub fn clear_all_subscriptions(&mut self)